@@ -2,5 +2,4 @@
 
 from .client import DLClient
 from .exception import DLException
-from .filter import DLFilter
-from .read_params import DLReadParams
+from .query import DLQuery
